@@ -2,4 +2,4 @@ from ..helpers import util
 
 
 def import_all():
-    util.import_all(__file__, __name__)
+    util.import_all(__name__)
