@@ -1,28 +1,24 @@
+import os
 from contextlib import ExitStack, contextmanager
-from os import environ
 from typing import Iterator, Mapping, Optional
 
 EnvValue = Optional[str]
 
 
 def _set_env(key: str, value: EnvValue) -> EnvValue:
-    last: EnvValue
-    try:
-        last = environ[key]
-    except KeyError:
-        last = None
+    last: EnvValue = os.getenv(key)
 
     if value is not None:
-        environ[key] = value
+        os.environ[key] = value
     elif last is not None:
-        del environ[key]
+        del os.environ[key]
+
     return last
 
 
 @contextmanager
 def push_env(key: str, value: EnvValue) -> Iterator[EnvValue]:
     saved = _set_env(key, value)
-
     try:
         yield saved
     finally:
