@@ -13,6 +13,7 @@ class GlobalOptions(GlobalOptionsBase):
     )
     saml_clients: Dict[str, SAMLClient] = field(default_factory=dict)
     log_dir: Optional[str] = None
+    session_length: Optional[int] = None
     aws_region: Optional[str] = None
     disable_analytics: bool = False
 
@@ -21,5 +22,6 @@ class GlobalOptions(GlobalOptionsBase):
             "debug": self.debug,
             "disable_analytics": self.disable_analytics,
             "saml_client": str(self.saml_client_type),
+            "session_length": str(self.session_length),
             "aws_region": str(self.aws_region),
         }
