@@ -4,14 +4,14 @@ import click
 from click_option_group import MutuallyExclusiveOptionGroup
 
 from sym.cli.constants.env import SYM_USE_CONTROL_MASTER
-from sym.cli.errors import CliError
+from sym.cli.errors import CliError, InvalidResource
 from sym.cli.helpers.ssh import check_ssh_version
 from sym.cli.helpers.util import flow
 
 from ..saml_clients.chooser import choose_saml_client
 from .config import Config
 from .envvar_option import EnvvarGroupedOption, EnvvarOption
-from .params import get_resource_env_vars
+from .params import get_profile, get_resource_env_vars
 
 
 def config_option(
@@ -45,8 +45,10 @@ def _resource_arg_callback(ctx, _param, resource: str):
         # twice, once with "None" value here.
         return None
     saml_client = choose_saml_client(ctx.parent.params["saml_client_name"])
-    if not resource or not saml_client.validate_resource(resource):
-        raise click.BadParameter(f"Invalid resource: {resource}")
+    if not resource:
+        raise click.BadParameter("Missing a resource!")
+    if (checked := saml_client.check_resource(resource)) :
+        return checked[0]
     return resource
 
 
