@@ -2,11 +2,12 @@ import logging
 from typing import Any, Callable, ClassVar, List
 
 from click import Command, Context, Group
+from click.exceptions import ClickException
 from sentry_sdk.api import push_scope
 
 from sym.cli.helpers.global_options import GlobalOptions
 
-from ..errors import get_active_env_vars
+from ..errors import UnknownError, get_active_env_vars
 from ..saml_clients.chooser import choose_saml_client
 from . import segment
 from .tee import Tee, TeeStdErr, TeeStdOut
@@ -94,7 +95,14 @@ class SymGroup(Group):
         else:
             logging.getLogger("segment").setLevel(logging.CRITICAL)
 
-        return super().invoke(ctx)
+        try:
+            return super().invoke(ctx)
+        except ClickException:
+            raise
+        except Exception as e:
+            if ctx.params.get("debug"):
+                raise e
+            raise UnknownError(e)
 
     def command(
         self, *args: Any, **kwargs: Any
