@@ -1,13 +1,14 @@
 import importlib
+import pkgutil
+import sys
 from functools import reduce, wraps
 from pathlib import Path
 from typing import Any, List
 
 
-def import_all(filename, name):
-    for path in Path(filename).resolve().parent.glob("*.py"):
-        if path.stem != "__init__":
-            importlib.import_module(f".{path.stem}", name)
+def import_all(name):
+    for _, module_name, _ in pkgutil.walk_packages(sys.modules[name].__path__):
+        importlib.import_module(f"{name}.{module_name}")
 
 
 def requires_all_imports(import_all):
