@@ -7,6 +7,7 @@ from . import import_all
 from .saml_client import SAMLClient
 
 SAMLClientName = Literal["auto", "aws-okta", "saml2aws", "aws-profile"]
+AUTO_EXCLUDED_SAML_CLIENT_NAMES = ["aws-profile"]
 
 
 @requires_all_imports(import_all)
@@ -20,7 +21,10 @@ def choose_saml_client(
 ) -> Optional[Type[SAMLClient]]:
     if saml_client_name == "auto":
         for client in SAMLClient.sorted_subclasses():
-            if has_command(client.binary):
+            if (
+                client.option_value not in AUTO_EXCLUDED_SAML_CLIENT_NAMES
+                and has_command(client.binary)
+            ):
                 return client
     else:
         for client in SAMLClient.sorted_subclasses():
