@@ -34,7 +34,9 @@ class Saml2Aws(SAMLClient):
     binary = "saml2aws"
     option_value = "saml2aws"
     priority = 10
-    setup_help = "Upgrade to the latest version, then run `saml2aws login`."
+    setup_help = (
+        f"Upgrade to the latest version (>= {MIN_VERSION}), then run `saml2aws login`."
+    )
 
     resource: str
     options: "GlobalOptionsBase"
@@ -85,7 +87,6 @@ class Saml2Aws(SAMLClient):
     @run_subprocess
     @command_require_bins(binary)
     def _exec(self, *args: str, **opts: str) -> Iterator[Tuple[Argument, ...]]:
-        self.log_subprocess_event(args)
         # saml2aws exec actually joins all the arguments into a single string and
         # runs it with the shell. So we have to use shlex.join to get around that!
         reparseable = shlex.join(keywords_to_options([*args, opts]))
@@ -118,6 +119,12 @@ class Saml2Aws(SAMLClient):
         except FailedSubprocessError:
             self._login(silence_stderr_=not self.debug, force=force, show_prompt=True)
 
+    @property
+    def _aws_session_duration(self) -> Optional[str]:
+        if self.session_length:
+            return str(self.session_length * 60)
+        return get_saml2aws_params().get("aws_session_duration")
+
     def _ensure_config(self, profile: Profile) -> ConfigParser:
         saml2aws_params = get_saml2aws_params()
         config = ConfigParser()
@@ -131,6 +138,7 @@ class Saml2Aws(SAMLClient):
                     "timeout": "0",
                     "aws_urn": "urn:amazon:webservices",
                     **saml2aws_params,
+                    "aws_session_duration": self._aws_session_duration,
                     "role_arn": profile.arn,
                     "region": profile.region,
                 }
