@@ -49,10 +49,8 @@ class TestWriteCreds:
         python -m pytest sym/cli/tests/commands/test_write_creds.py::TestWriteCreds::test_execute_write_creds
     """
 
-    def test_execute_write_creds(
-        self, sandbox, credentials_path, creds_env, capture_command
-    ):
-        with self.write_creds_context_manager(capture_command, sandbox, creds_env):
+    def test_execute_write_creds(self, setup, credentials_path, creds_env):
+        with setup():
             global_options = GlobalOptions(saml_client_type=AwsOkta)
 
             request_data = RequestData(
@@ -67,13 +65,28 @@ class TestWriteCreds:
             written_creds = self.get_credentials_from_file(credentials_path, TEST_PROFILE)
             expect(written_creds).to(have_keys(creds_env))
 
-    def test_execute_write_creds_without_aws_okta_fails(
-        self, sandbox, credentials_path, capture_command, creds_env
-    ):
+    @patch("sym.cli.saml_clients.saml_client.SAMLClient.write_creds")
+    def test_execute_write_creds_prefix(self, mock_write_creds, setup, credentials_path):
+        with setup():
+            global_options = GlobalOptions(saml_client_type=AwsOkta)
+
+            request_data = RequestData(
+                action="write_creds",
+                resource=TEST_RESOURCE,
+                global_options=global_options,
+                params={"path": credentials_path, "prefix": "foo"},
+            )
+            action = WriteCredsAction()
+            action.execute(request_data)
+
+            mock_write_creds.assert_called_once_with(
+                path=credentials_path,
+                profile=f"foo-{TEST_RESOURCE}",
+            )
+
+    def test_execute_write_creds_without_aws_okta_fails(self, setup, credentials_path):
         with pytest.raises(CliError, match="Unable to find aws-okta in your path!"):
-            with self.write_creds_context_manager(
-                capture_command, sandbox, create_binary=False
-            ):
+            with setup(create_binary=False):
                 global_options = GlobalOptions(saml_client_type=AwsOkta)
 
                 request_data = RequestData(
@@ -87,12 +100,16 @@ class TestWriteCreds:
 
     @patch("sym.cli.saml_clients.saml_client.SAMLClient._ensure_session")
     def test_execute_write_creds_expiring_force_ensures_session(
-        self, _ensure_session, sandbox, credentials_path, capture_command, creds_env
+        self,
+        mock_ensure_session,
+        setup,
+        credentials_path,
+        creds_env,
     ):
         creds = copy(creds_env)
         creds["AWS_OKTA_SESSION_EXPIRATION"] = str(int(datetime.now().timestamp()))
 
-        with self.write_creds_context_manager(capture_command, sandbox, creds):
+        with setup(creds=creds):
             global_options = GlobalOptions(saml_client_type=AwsOkta)
 
             request_data = RequestData(
@@ -105,7 +122,7 @@ class TestWriteCreds:
             action = WriteCredsAction()
             action.execute(request_data)
 
-            _ensure_session.assert_called_once_with(force=True)
+            mock_ensure_session.assert_called_once_with(force=True)
 
             written_creds = self.get_credentials_from_file(credentials_path, TEST_PROFILE)
 
@@ -123,20 +140,18 @@ class TestWriteCreds:
     @patch("sym.cli.saml_clients.saml_client.SAMLClient._ensure_session")
     def test_execute_write_creds_profile_mismatch_force_ensures_session(
         self,
-        _ensure_session,
-        _profile_match,
-        sandbox,
+        mock_ensure_session,
+        mock_profile_match,
+        setup,
         credentials_path,
-        capture_command,
         creds_env,
     ):
-        creds = copy(creds_env)
-
+        creds = creds_env.copy()
         # _profile_matches_caller_identity doesn't get called if creds are expiring
         future_datetime = datetime.now() + timedelta(minutes=30)
         creds["AWS_OKTA_SESSION_EXPIRATION"] = str(int(future_datetime.timestamp()))
 
-        with self.write_creds_context_manager(capture_command, sandbox, creds):
+        with setup(creds=creds):
             global_options = GlobalOptions(saml_client_type=AwsOkta)
 
             request_data = RequestData(
@@ -149,8 +164,8 @@ class TestWriteCreds:
             action = WriteCredsAction()
             action.execute(request_data)
 
-            _profile_match.assert_called_once()
-            _ensure_session.assert_called_once_with(force=True)
+            mock_profile_match.assert_called_once()
+            mock_ensure_session.assert_called_once_with(force=True)
 
             written_creds = self.get_credentials_from_file(credentials_path, TEST_PROFILE)
 
@@ -162,29 +177,38 @@ class TestWriteCreds:
         command_login_tester(["write-creds"], {"SYM_RESOURCE": TEST_RESOURCE})
         command_login_tester(["write-creds"], {"ENVIRONMENT": TEST_RESOURCE})
 
+    @patch.object(WriteCredsAction, "write_creds")
     def test_write_creds_command_executes_correct_action_with_params(
-        self, simple_command_tester, capture_command, creds_env, credentials_path, sandbox
+        self,
+        mock_write_creds,
+        setup,
+        simple_command_tester,
+        credentials_path,
+        sandbox,
     ):
-        with self.write_creds_context_manager(capture_command, sandbox, creds_env):
+        with setup():
             sandbox.create_binary(f"bin/aws")
             sandbox.create_binary(f"bin/session-manager-plugin")
 
-            with patch.object(WriteCredsAction, "write_creds") as mock_write_creds:
-                result = simple_command_tester(
-                    [
-                        "write-creds",
-                        TEST_RESOURCE,
-                        "--profile",
-                        TEST_PROFILE,
-                        "--path",
-                        str(credentials_path),
-                    ],
-                )
+            result = simple_command_tester(
+                [
+                    "write-creds",
+                    TEST_RESOURCE,
+                    "--profile",
+                    TEST_PROFILE,
+                    "--path",
+                    str(credentials_path),
+                ],
+            )
 
-                assert result.exit_code == 0
-                mock_write_creds.assert_called_once_with(
-                    TEST_RESOURCE, ANY, str(credentials_path), TEST_PROFILE
-                )
+            assert result.exit_code == 0
+            mock_write_creds.assert_called_once_with(
+                TEST_RESOURCE,
+                ANY,
+                str(credentials_path),
+                TEST_PROFILE,
+                "sym",
+            )
 
     ##############################################################################################
     # SECTION 2
@@ -233,43 +257,13 @@ class TestWriteCreds:
 
         return creds_dict
 
-    @contextmanager
-    def write_creds_context_manager(
-        self,
-        capture_command: CaptureCommand,
-        sandbox: Sandbox,
-        creds_env: Optional[Dict[str, str]] = None,
-        create_binary: bool = True,
-    ):
-        """Load all required context for executing WriteCredsAction.
-
-        Initializes capture_command for stubbing subprocesses,
-        stubs the process to get creds from the environment,
-        simulates a sym login with the "sym" org and "y@symops.io" email,
-        and initializes a sandbox with an AwsOkta binary.
-
-        See test_execute_write_creds as an example of usage.
-
-        Args:
-            capture_command: instance of CaptureCommand to stub subprocesses
-            sandbox: instance of Sandbox to keep tests isolated
-            creds_env: key/value pairs to set as the result for the subprocess
-                that retrieves creds from the local environment
-            create_binary: whether to create the AwsOkta binary
-        """
-
-        if not creds_env:
-            creds_env = {}
-
-        with capture_command():
-            capture_command.register_output(r"env", _env_str(creds_env))
-
-            with sandbox.push_xdg_config_home():
-                Config.instance()["org"] = "sym"
-                Config.instance()["email"] = "y@symops.io"
-
-                if create_binary:
-                    sandbox.create_binary(f"bin/{AwsOkta.binary}")
-
-                with sandbox.push_exec_path():
+    @pytest.fixture
+    def setup(self, capture_command, click_setup, creds_env):
+        @contextmanager
+        def _setup(create_binary=True, creds=creds_env):
+            with click_setup(set_client=create_binary):
+                with capture_command():
+                    capture_command.register_output(r"env", _env_str(creds))
                     yield
+
+        return _setup
